@@ -1,11 +1,11 @@
 """Module for plotting Numpy-like 1D histograms to the terminal."""
 
-from __future__ import division
-from itertools import cycle
 
-import sys
-import numpy as np
+from itertools import cycle
+from typing import Optional
+
 import click
+import numpy as np
 
 DEFAULT_SYMBOLS = " |=/\\"
 COMPOSING_SYMBOLS = "/\\"
@@ -15,12 +15,12 @@ DEFAULT_BG_COLORS = "K0000"
 __all__ = ["print_hist", "text_hist", "HistFormatter"]
 
 
-class Hixel(object):
+class Hixel:
     """The smallest unit of a histogram plot."""
 
     def __init__(self, char=" ", fg="0", bg="0", use_color=True, compose=" "):
         self.character = " "
-        self.compose = compose
+        self.compose: Optional[str] = compose
         self.fg_color = fg
         self.bg_color = bg
         self.use_color = use_color
@@ -29,9 +29,9 @@ class Hixel(object):
     def add(self, char=" ", fg="0", bg="0"):
         """Add another element on top."""
 
-        allowed = " =|\/"
+        allowed = r" =|\/"
         if char not in allowed:
-            raise ValueError("Symbol not one of the allowed: '%s'" % (allowed,))
+            raise ValueError(f"Symbol not one of the allowed: '{allowed}'")
 
         if fg == self.fg_color:
             # Combine characters if possible
@@ -49,7 +49,7 @@ class Hixel(object):
                 (" ", "/"): "/",
             }
             if char in compose_chars:
-                self.compose = compose_combinations.get((self.compose, char))
+                self.compose = compose_combinations.get((self.compose, char))  # type: ignore
             else:
                 self.character = char_combinations.get((self.character, char), char)
         elif char != " ":
@@ -75,7 +75,7 @@ class Hixel(object):
             # Replace BG colour with opposite brightness,
             # so it shows when the text is selected in a terminal.
             ret += self.ansi_color_string(self.bg_color, self.bg_color.swapcase())
-            ret += u"\u2588"
+            ret += "\u2588"
         else:
             ret += self.ansi_color_string(self.fg_color, self.bg_color)
             ret += self.substitute_character(self.character, self.compose)
@@ -99,13 +99,13 @@ class Hixel(object):
         """
 
         subs = {
-            "|": u"\u2502",
-            "=": u"\u2550",
-            "#": u"\u256A",
-            "\\": u"\u20e5",
-            "/": u"\u20eb",
-            "X": u"\u20e5\u20eb",
-            None: u"",
+            "|": "\u2502",
+            "=": "\u2550",
+            "#": "\u256A",
+            "\\": "\u20e5",
+            "/": "\u20eb",
+            "X": "\u20e5\u20eb",
+            None: "",
         }
 
         ret = subs.get(char, char)
@@ -113,7 +113,7 @@ class Hixel(object):
         # This looks ugly if some Hixels of a histogram are covered by another and some are not.
         # Unless explicitly asked for no compositio, if no composition is added,
         # use empty composition character to make them all display the same.
-        ret += subs.get(compose, u"\u034f")
+        ret += subs.get(compose, "\u034f")
 
         return ret
 
@@ -148,7 +148,7 @@ class Hixel(object):
         return ret
 
 
-class BinFormatter(object):
+class BinFormatter:
     """Class that turns bin contents into text.
 
     Parameters
@@ -262,7 +262,7 @@ class BinFormatter(object):
                 self.compose = " "
                 break
         else:
-            self.compose = None
+            self.compose = None  # type: ignore
 
         # Format bin
         bin_string = ""
@@ -320,7 +320,7 @@ class BinFormatter(object):
         return " " * self.tick_format_width + self.no_tick_mark
 
 
-class HistFormatter(object):
+class HistFormatter:
     """Class that handles the formating of histograms.
 
     Parameters
@@ -357,9 +357,9 @@ class HistFormatter(object):
         columns=None,
         scale_bin_width=True,
         title="",
-        labels=[""],
+        labels=("",),
         summary=False,
-        **kwargs
+        **kwargs,
     ):
         self.title = title
         self.edges = edges
@@ -448,7 +448,7 @@ class HistFormatter(object):
         hist_string += self.bin_formatter.tick(top[0])
         longest_count = tot_c[np.argmax(c)]
         if np.issubdtype(longest_count.dtype, np.integer):
-            hist_string += (u"{: %dd} \u2577\n" % (hist_width - 2,)).format(
+            hist_string += ("{: %dd} \u2577\n" % (hist_width - 2,)).format(
                 longest_count
             )
         else:
@@ -457,7 +457,7 @@ class HistFormatter(object):
             # The tick value
             hist_string += self.bin_formatter.tick_format % (longest_count,)
             # The tick
-            hist_string += u"\u2577\n"
+            hist_string += "\u2577\n"
 
         # Write the bins
         for c, t, b, w in zip(counts.T, top, bottom, self.bin_lines):
@@ -480,7 +480,7 @@ class HistFormatter(object):
 
         # First line: symbol, label
         summary += "     "
-        for c, l, s, fg, bg in zip(
+        for _, l, s, fg, bg in zip(
             counts,
             cycle(self.labels),
             cycle(self.bin_formatter.symbols),
@@ -488,7 +488,7 @@ class HistFormatter(object):
             cycle(self.bin_formatter.bg_colors),
         ):
             # Pad label to make room for numbers below
-            l = "%-9s" % (l,)
+            l = f"{l:<9}"
             label = " "
             label += Hixel(
                 s, fg, bg, self.bin_formatter.use_color, self.bin_formatter.compose
@@ -507,14 +507,14 @@ class HistFormatter(object):
         summary += " " * pad + "Tot:"
         for c, w in zip(counts, label_widths):
             tot = np.sum(c)
-            summary += " % .2e" % (tot,) + " " * (w - 10)
+            summary += f" {tot: .2e}" + " " * (w - 10)
         summary += "\n"
 
         # Third line: Average
         summary += " " * pad + "Avg:"
         for c, w in zip(counts, label_widths):
             average = np.average(bin_values, weights=c)
-            summary += " % .2e" % (average,) + " " * (w - 10)
+            summary += f" {average: .2e}" + " " * (w - 10)
         summary += "\n"
 
         # Fourth line: std
@@ -522,25 +522,50 @@ class HistFormatter(object):
         for c, w in zip(counts, label_widths):
             average = np.average(bin_values, weights=c)
             std = np.sqrt(np.average((bin_values - average) ** 2, weights=c))
-            summary += " % .2e" % (std,) + " " * (w - 10)
+            summary += f" {std: .2e}" + " " * (w - 10)
         summary += "\n"
 
         return summary
 
 
+def get_plottable_protocol_bin_edges(axis):
+    """Get histogram bin edges from PlottableAxis.
+
+    Borrowed from ``mplhep.utils``.
+
+    """
+
+    out = np.empty(len(axis) + 1)
+    assert isinstance(
+        axis[0], tuple
+    ), f"Currently only support non-discrete axes {axis}"
+    # TODO: Support discreete axes
+    out[0] = axis[0][0]
+    out[1:] = [axis[i][1] for i in range(len(axis))]  # type: ignore
+    return out
+
+
 def get_count_edges(hist):
     """Get bin contents and edges from a compatible histogram."""
 
-    # Try the boost-histogram interface
+    # Try the PlottableProtocol
     try:
-        hist = hist.to_numpy()
-    except:
+        count = hist.values()
+        edges = get_plottable_protocol_bin_edges(hist.axes[0])
+        # Each bin comes with both upper and lower edge
+        # Merge
+        hist = count, edges
+    except Exception:
         pass
 
-    # Try the uproot interface
+    # Try generic numpy conversion methods
+    try:
+        hist = hist.to_numpy()
+    except Exception:
+        pass
     try:
         hist = hist.numpy()
-    except:
+    except Exception:
         pass
 
     # Try the Numpy interface
@@ -552,7 +577,7 @@ def get_count_edges(hist):
     return count, edges
 
 
-def print_hist(hist, file=click.get_text_stream("stdout"), **kwargs):
+def print_hist(hist, file=click.get_text_stream("stdout"), **kwargs):  # noqa: B008
     """Plot the output of ``numpy.histogram`` to the console.
 
     Parameters
