@@ -1,4 +1,5 @@
 import numpy as np
+
 from histoprint import *
 
 
@@ -51,7 +52,7 @@ def test_boost():
 
     try:
         import boost_histogram as bh
-    except:
+    except ModuleNotFoundError:
         return
 
     hist = bh.Histogram(bh.axis.Regular(20, -3, 3))
@@ -63,9 +64,9 @@ def test_uproot():
     """Test uproot hsitograms if it is available."""
 
     try:
-        import uproot
         import awkward
-    except:
+        import uproot
+    except ModuleNotFoundError:
         return
 
     with uproot.open("tests/data/histograms.root") as F:
@@ -74,7 +75,7 @@ def test_uproot():
     try:
         # Works with uproot 3
         hist.show()
-    except:
+    except Exception:
         pass
     print_hist(hist, title="uproot TH1")
 
